---
title: '[2023년 12월] 서비스이용약관 개정 변경안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-11-23T15:00:00.000Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.

2023년 12월 01일 아래와 같이 서비스 이용약관이 변경됨을 사전 안내 드립니다.

- 공고일 : 2023.11.24(금)
- 시행일 : 2023.12.01(금)
